==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/FormatSpecifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSpecifierDescription } from "./FormatSpecifierDescription";
/**
 * @hidden
 */
export let FormatSpecifierDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatSpecifierDescriptionMetadata extends Base {
        static b(a) {
            if (FormatSpecifierDescriptionMetadata.a == null) {
                FormatSpecifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatSpecifierDescriptionMetadata.c(FormatSpecifierDescriptionMetadata.a);
            }
            if (a.j(FormatSpecifierDescriptionMetadata.a)) {
                return;
            }
            a.y(FormatSpecifierDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            FormatSpecifierDescriptionMetadata.b(a);
            a.aa("FormatSpecifier", () => new FormatSpecifierDescription());
            a.z("FormatSpecifier", FormatSpecifierDescriptionMetadata.a);
        }
    }
    FormatSpecifierDescriptionMetadata.$t = /*@__PURE__*/ markType(FormatSpecifierDescriptionMetadata, 'FormatSpecifierDescriptionMetadata');
    FormatSpecifierDescriptionMetadata.a = null;
    return FormatSpecifierDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FormatSpecifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSpecifierDescription } from "./FormatSpecifierDescription";
/**
 * @hidden
 */
export let FormatSpecifierDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatSpecifierDescriptionMetadata extends Base {
        static b(a) {
            if (FormatSpecifierDescriptionMetadata.a == null) {
                FormatSpecifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatSpecifierDescriptionMetadata.c(FormatSpecifierDescriptionMetadata.a);
            }
            if (a.k(FormatSpecifierDescriptionMetadata.a)) {
                return;
            }
            a.aa(FormatSpecifierDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            FormatSpecifierDescriptionMetadata.b(a);
            a.ac("FormatSpecifier", () => new FormatSpecifierDescription());
            a.ab("FormatSpecifier", FormatSpecifierDescriptionMetadata.a);
        }
    }
    FormatSpecifierDescriptionMetadata.$t = /*@__PURE__*/ markType(FormatSpecifierDescriptionMetadata, 'FormatSpecifierDescriptionMetadata');
    FormatSpecifierDescriptionMetadata.a = null;
    return FormatSpecifierDescriptionMetadata;
})();
